linguafilter
============

.. image:: https://travis-ci.org/benweedon/linguafilter.svg?branch=master
    :target: https://travis-ci.org/benweedon/linguafilter
    :alt: Travis Test Status
.. image:: https://coveralls.io/repos/github/benweedon/linguafilter/badge.svg?branch=master
    :target: https://coveralls.io/github/benweedon/linguafilter?branch=master
    :alt: Test Coverage
.. image:: https://img.shields.io/pypi/v/linguafilter.svg
    :target: https://pypi.python.org/pypi/linguafilter
    :alt: PyPi
.. image:: https://img.shields.io/pypi/pyversions/linguafilter.svg
    :target: https://pypi.python.org/pypi/linguafilter
    :alt: Python Versions

A pandoc filter adding support for various linguistics constructs
